<?php

//include the config file
require dirname(__FILE__) . '/config.php';

//load status page after a few seconds
//do not do this too often! :-)
//the header refresh is not supported by al browser
//add this before any output to the browser
header('Refresh:' . $statusRefreshInSeconds . '; url=status.php');

//include the AWS SDK
require $awsSdkPath;

//include the require AWS SDK namespaces
use Aws\Ec2\Ec2Client;
use Aws\Exception\AwsException;
use Aws\S3\Exception\Ec2Exception;

//configure the AWS API client
$client = new Aws\Ec2\Ec2Client([
    'region' => $awsRegion,
    'version' => $awsSdkVersion,
    'credentials' => [
        'key' => $apiKey,
        'secret' => $apiSecret,
    ],
        ]);

try {
    $result = $client->describeInstances([
        'DryRun' => false, //check whether you have the required permissions for the action
        'IncludeAllInstances' => true, //includes all or only running instances
        'InstanceIds' => $instanceIds //the instance id's you would like to check
    ]);

    $reservations = $result['Reservations'];
    if ($reservations) {
        foreach ($reservations as $reservation) {
            $instances = $reservation['Instances'];
            foreach ($instances as $instance) {

                $instanceName = '';
                foreach ($instance['Tags'] as $tag) {
                    if ($tag['Key'] == 'Name') {
                        $instanceName = $tag['Value'];
                    }
                }

                echo '<p>';
                echo 'Instance Name: ' . $instanceName . '<br>';

                if ($instance['State']['Name'] == AWS_RUNNING) {
                    $color = COLOR_GOOD;
                } else if ($instance['State']['Name'] == AWS_PENDING || $instance['State']['Name'] == AWS_STOPPING || $instance['State']['Name'] == AWS_SHUTDOWN) {
                    $color = COLOR_WARN;
                } else {
                    $color = COLOR_BAD;
                }

                echo '--> State: <span style="color: ' . $color . '; font-weight: bold">' . $instance['State']['Name'] . '</span><br>';

                echo '--> Instance ID: ' . $instance['InstanceId'] . '<br>';
                echo '</p>';
            }
        }
    } else {
        //in case api response returns zero results
        echo '<p><b>ERROR: </b><BR>';
        echo 'No instances found.' . '</p>';
    }
} catch (Ec2Exception $e) {
    //catch EC2 specific exception
    echo '<p><b>ERROR: </b><BR>';
    echo $e->getMessage() . '</p>';
} catch (AwsException $e) {
    //catch general AWS exception
    echo '<p><b>ERROR: </b><BR>';
    echo $e->getAwsErrorCode() . "</p>";
}

echo '<p>Checking status in ' . $statusRefreshInSeconds . ' seconds...</p>';
